<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       ivi_mollie
 * @since      1.0.0
 *
 * @package    Ivi_mollie
 * @subpackage Ivi_mollie/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Ivi_mollie
 * @subpackage Ivi_mollie/admin
 * @author     Ivascu Madalin <madalinivascu@gmail.com>
 */
class Ivi_mollie_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
	private $statusMaping = [
		'open'=>'processing',
		'cancelled'=>'cancelled',
		'pending'=>'pending',
		'paid'=>'completed',
		'failed'=>'failed'
		];
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		 
		 add_action( 'rest_api_init',array( $this,'registerRoute'));
         $this->mollie = new Mollie_API_Client;
         $this->mollie->setApiKey("test_QWecGKzDsTrB2GqU9sEkucBNsvu3qr");	

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Ivi_mollie_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Ivi_mollie_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/ivi_mollie-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Ivi_mollie_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Ivi_mollie_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		// wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/ivi_mollie-admin.js', array( 'jquery' ), $this->version, false );

	}
	public function registerRoute()
	{
		 
		  register_rest_route( 'mollie/v1', '/generate-url', array(
		    'methods' => 'POST',
		    'callback' => array($this,'returnMollieUrl'),
		    'args' => array(),
		  ));
		   register_rest_route( 'mollie/v1', '/payment-status', array(
		    'methods' => 'POST',
		    'callback' => array($this,'setStatus'),
		    'args' => array(),
		  ));
		   register_rest_route( 'mollie/v1', '/success', array(
		    'methods' => 'GET',
		    'callback' => array($this,'showSucess'),
		    'args' => array(),
		  ));
		    register_rest_route( 'mollie/v1/simple/', '/generate-url', array(
		    'methods' => 'POST',
		    'callback' => array($this,'returnSimpleMollieUrl'),
		    'args' => array(),
		  ));
		   register_rest_route( 'mollie/v1/simple/', '/payment-status', array(
		    'methods' => 'POST',
		    'callback' => array($this,'setWooStatus'),
		    'args' => array(),
		  ));
		   register_rest_route( 'mollie/v1/simple/', '/success', array(
		    'methods' => 'GET',
		    'callback' => array($this,'showSucess'),
		    'args' => array(),
		  ));
	}

	public function returnSimpleMollieUrl($request)
	{
		$userCookie = $request->get_param('user');
		$porducts = $request->get_param('products');
		$id = wp_validate_auth_cookie(urldecode($userCookie),'logged_in');
		if (!$id) {
			return new WP_Error( 'invalid_auth_cookie', 'You are not logged in', array( 'status' => 404 ) );
		}

		try
		{
			//create woocommmerce order
			$order = wc_create_order([
				'customer_id' => $id,
			]);
			foreach ($products as $product) {
				$order->add_product( get_product($product->id), $product->qty);
			}
			$order->calculate_totals();
			$total = $order->get_total();
			$orderNumber = $order->get_order_number(); 


           //create mollie payment
	       	$paymentdata = array(
				"amount"        => $total,
			    'description'   => 'Payment for order: '.$orderNumber,
				"redirectUrl"   => get_rest_url().'mollie/v1/simple/success',
				"webhookUrl"    => get_rest_url().'mollie/v1/simple/payment-status',
				"metadata" => array(
					"user_id" => $id,
					"order"=>$order->id
				),
			);
        	 $payment = $this->doPayment($paymentdata);
        	 $url = $payment->getPaymentUrl();
    	}
		catch (Mollie_API_Exception $e)
		{
			return json_encode(['status'=>'error','error'=>htmlspecialchars($e->getMessage())]);
		}
		return new WP_REST_Response(['status'=>'ok','url'=> $url]);

	}
public function setWooStatus($request)
{
		$id = $request->get_param('id');
		try {
			$payment  = $this->mollie->payments->get($id);
		    $uid = $payment->metadata->user_id;

		    $status = $this->statusMaping[$payment->status];
		    $order = $payment->metadata->order;
		    $order = new WC_Order($order);
			$order->update_status($status);

		} catch (Mollie_API_Exception  $e) {
			echo "API call failed: " . htmlspecialchars($e->getMessage());
			// $database =get_home_path()."payment.log";
		 //    file_put_contents($database,htmlspecialchars($e->getMessage()));
		}
}














	public function showSucess($request)
	{
		echo "Payment is processing, please close this window";
	}
	public function setStatus($request)
	{
		
		$id = $request->get_param('id');
		try {
			$payment  = $this->mollie->payments->get($id);
		    $uid = $payment->metadata->user_id;


		    $status = $this->statusMaping[$payment->status];
		    $woo_submition = $payment->metadata->woo_submition;


		    $product = wc_get_product($woo_submition);
			$order = wc_create_order([
				'customer_id' => $uid,
				'status' =>$status 
			]);
			$order->add_product($product);
			$order->calculate_totals();
			$database =get_home_path()."payment.log";

		    file_put_contents($database,json_encode($order));

		    update_user_meta( $uid, 'sup_value', $payment->status);
		    update_user_meta( $uid, 'sup_id', $id);
		} catch (Mollie_API_Exception  $e) {
			echo "API call failed: " . htmlspecialchars($e->getMessage());
			$database =get_home_path()."payment.log";
		    file_put_contents($database,htmlspecialchars($e->getMessage()));
		}
		
	}
	public function returnMollieUrl($request)
	{
		$userCookie = $request->get_param('user');
		$id = wp_validate_auth_cookie(urldecode($userCookie),'logged_in');
		if (!$id) {
			return new WP_Error( 'invalid_auth_cookie', 'You are not logged in', array( 'status' => 404 ) );
		}
		$mail = get_userdata($id)->data->user_email;
		$fname = get_user_meta($id, 'first_name',true);
		$lname = get_user_meta($id, 'last_name',true);
		$no_bottles = get_user_meta($id, 'no_bottles',true);
		$type_o_box = get_user_meta($id, 'type_o_box',true);
		$amount = 29;
		if($no_bottles == '3') {
		    if($type_o_box =='liefhebber') {
		      $woo_submition = 21795;
		      $amount = 29;
		    } else if($type_o_box =='kenner') {
		      $woo_submition = 21794;
		      $amount = 39;
		    }
		  } else if($no_bottles == '6') {
		      if($type_o_box =='liefhebber') {
		      $woo_submition = 21797;
		      $amount = 58;
		    } else if($type_o_box =='kenner') {
		      $woo_submition = 21796;
		      $amount = 78;
		    }
		  }
		$data = array(
			"name"     => $fname.' '.$lname,
			"email"    => $mail,
			"metadata" => array(
				"user_id" => $id,
			));

		try
		{
        	 $customer = $this->createCustomer($data);
	        	 $paymentdata = array(
				"amount"        => $amount,
				'customerId'    => $customer->id,
			    'recurringType' => 'first',       // important
			    'description'   => 'First payment for: '.$fname.' '.$lname,
				"redirectUrl"   => get_rest_url().'mollie/v1/success',
				"webhookUrl"    => get_rest_url().'mollie/v1/payment-status',
				"metadata" => array(
					"user_id" => $id,
					"woo_submition"=>$woo_submition
				),

				// Flag this payment as a first payment to allow recurring payments later.
				"recurringType" => Mollie_API_Object_Payment::RECURRINGTYPE_FIRST,
			);
        	 $payment = $this->doPayment($paymentdata);
   //      	 $subscriptionData = [
			//     "amount"      => 25.00,
			//     "times"       => 4,
			//     "interval"    => "3 days",
			//     "description" => "dayly payment",
			// ];
			//$subscription = $this->doSubscription($customer->id,$subscriptionData);
        	 $url = $payment->getPaymentUrl();
    	}
		catch (Mollie_API_Exception $e)
		{
			return json_encode(['status'=>'error','error'=>htmlspecialchars($e->getMessage())]);
		}
		return new WP_REST_Response(['status'=>'ok','url'=> $url]);
	}
	public function createCustomer($data)
	{
		return $this->mollie->customers->create($data);
	}
	public function doPayment($data)
	{
		return  $this->mollie->payments->create($data);
	}
	public function doSubscription($customer,$data)
	{
		return $mollie->customers_subscriptions->withParentId($customer)->create($data);
	}

}
