<?php
/**
 * DFD themes functions
 */
if ( ! defined( 'ABSPATH' ) ) { exit; }

define('DFD_THEME_SETTINGS_NAME', 'native');

if (!isset($content_width)) {
	$content_width = 1200;
}

// Make theme available for translation
load_theme_textdomain('dfd-native', get_template_directory() . '/lang');

# Including theme components
require_once get_template_directory().'/inc/includes.php';

add_action('after_setup_theme', 'dfd_themes_setup_theme');

if (!function_exists('dfd_themes_setup_theme')) {
	/**
	 * Enqueues core theme functionality
	 *
	 * @return true
	 */
	function dfd_themes_setup_theme() {

		// Enqueue theme scripts and styles
		add_action('wp_enqueue_scripts', 'dfd_themes_scripts', 100);
		
		// Enqueue admin scripts and styles
		add_action('admin_enqueue_scripts', 'dfd_themes_admin_scripts');

		add_filter('wp_get_attachment_link', 'dfd_kadabra_prettyadd');
		
		add_filter('excerpt_length', 'dfd_kadabra_excerpt_length', 999 );
		add_filter('next_posts_link_attributes', 'dfd_kadabra_posts_link_attributes_1');
		add_filter('previous_posts_link_attributes', 'dfd_kadabra_posts_link_attributes_2');
		
		// Disable default gallery style
		add_filter( 'use_default_gallery_style' , 'dfd_kadabra_use_default_gallery_style_filter' );
		
		// Register wp_nav_menu() menus
		register_nav_menus(array(
			'primary_navigation' => esc_html__('Primary Navigation', 'dfd-native'),
			'top_left_navigation' => esc_html__('Top Left Navigation (for header style 3 and 4)', 'dfd-native'),
			'top_right_navigation' => esc_html__('Top Right Navigation (for header style 3 and 4)', 'dfd-native'),
			'second_builder_navigation' => esc_html__('Second Navigation (for header builder)', 'dfd-native'),
			'third_builder_navigation' => esc_html__('Third Navigation (for header builder)', 'dfd-native'),
			'additional_header_menu' => esc_html__('Additional header navigation', 'dfd-native'),
			'footer_menu' => esc_html__('Footer navigation', 'dfd-native'),
		));

		// Add post thumbnails (http://codex.wordpress.org/Post_Thumbnails)
		add_theme_support('post-thumbnails');

		// Add post formats (http://codex.wordpress.org/Post_Formats)
		add_theme_support('post-formats', array('gallery','video','quote','audio','link'));
		
		add_theme_support( 'automatic-feed-links' );
		
		add_theme_support( 'title-tag' );

		add_post_type_support('page', 'excerpt');
		
		// Set default values for the upload media box
		add_action('switch_theme','dfd_theme_setup');
		
		if(class_exists('WooCommerce')) {
			dfd_themes_woocommerce_support();
		}
		
		/*
		Visual Composer theme integration
		*/
		if ( class_exists( 'Vc_Manager', false ) ) {

			if ( function_exists( 'vc_set_as_theme' ) ) {
				add_action( 'vc_before_init', 'dfd_vc_set_as_theme' );
				function dfd_vc_set_as_theme() {
					vc_set_as_theme();
				}
			}

			if ( function_exists( 'vc_set_default_editor_post_types' ) ) {
				vc_set_default_editor_post_types( array( 'page', 'post', 'portfolio' ) );
			}
		}
	}
}

if (!function_exists('dfd_theme_setup')) {
	/**
	 * Defines image sizes and Wishlist plugin shortcode position
	 *
	 * @return true
	 */
	function dfd_theme_setup() {
		// Set default values for the upload media box
		update_option( 'image_default_link_type', 'none' );
		update_option( 'image_default_size', 'large' );
		update_option( 'yith_wcwl_button_position', 'shortcode' );
	}
}

if (!function_exists('dfd_themes_woocommerce_support')) {
	/**
	 * WooCommerce support
	 *
	 * @return true
	 */
	function dfd_themes_woocommerce_support() {
		add_theme_support( 'woocommerce' );

		# star rating for proucts in loop
		add_filter('woocommerce_add_to_cart_fragments', 'woocommerce_header_add_to_cart_fragment');
		if (function_exists('dfd_woocommerce_disable_styles')) {
			dfd_woocommerce_disable_styles();
		}
		
		# Hook in on activation
		global $pagenow;
		if ( is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ) {
			add_action( 'init', 'dfd_kadabra_woocommerce_image_dimensions', 1 );
		}
	}
}


//add_filter( 'woocommerce_enqueue_styles', '__return_false' );
//add_filter('show_admin_bar', '__return_false');
//function my_admin() {
//	wp_enqueue_style('admin_styles' , get_template_directory_uri().'/css/admin_section.css', false);
//}
//	add_action('admin_enqueue_scripts', 'my_admin');
//	add_action('login_enqueue_scripts', 'my_admin');

// DEFINE API GATEWAY
//add_filter( 'json_url_prefix', function( $prefix ) { return 'jason'; } );



add_action( 'wp_enqueue_scripts', 'new_woo' );
function new_woo(){
	wp_register_style( 'mywoo', get_template_directory_uri() . '/css/comerce.css' );
	
	if ( class_exists( 'woocommerce' ) ) {
		wp_enqueue_style( 'mywoo' );
	}
}


function new_styles() {
  wp_enqueue_style( 'style', get_stylesheet_uri() );
  wp_enqueue_style( 'winestyle', get_template_directory_uri() . '/css/extra.css');
}
add_action( 'wp_enqueue_scripts', 'new_styles' );


// Admin Tracking Columns //
add_filter ( 'manage_wine_posts_columns', 'add_acf_columns' );
function add_acf_columns ( $columns ) {
	return array_merge ( $columns, array ( 
		'winery_name' => __ ( 'Winery' ),
		'selling_price'   => __ ( 'Selling Price' ),
		'buying_price'   => __ ( 'Buying Price' ),
		'vintage' => __ ( 'Vintage' ),
		'country' => __ ( 'Country' ),
		'region' => __ ( 'Region' ),
		'wine_type' => __ ( 'Wine type' )
	) );
}

function wine_custom_column ( $column, $post_id ) {
	switch ( $column ) {
		case 'vintage':
			echo get_post_meta ( $post_id, 'vintage', true );
		break;
		case 'selling_price':
			echo get_post_meta ( $post_id, 'selling_price', true );
			echo ' €';
		break;
		case 'buying_price':
			echo get_post_meta ( $post_id, 'buying_price', true );
			echo ' €';
		break;
		case 'country':
			echo get_post_meta ( $post_id, 'country', true );
		break;
		case 'wine_type':
			echo get_post_meta ( $post_id, 'wine_type', true );
		break;
		case 'region':
			echo get_post_meta ( $post_id, 'region', true );
		break;
		case 'winery_name':
			echo get_post_meta ( $post_id, 'winery_name', true );
		break;
	}
}
add_action ( 'manage_wine_posts_custom_column', 'wine_custom_column', 10, 2 );
//### END ###//

// REMOVE USER ROLES
remove_role( 'contributor' );
remove_role( 'author' );
//### END ###//

// NEW ROLES
add_role('follower', __('Follower'),
    array(
        'read'              => true,
        'create_posts'      => true,
        'edit_posts'        => true,
        'edit_others_posts' => true,
        'publish_posts'     => true,
        'manage_categories' => true,
        )
);

// BUYING WINES //
add_filter('woocommerce_get_price','druyf_get_price',20,2);
function druyf_get_price($price,$post){
	if ($post->post->post_type === 'wine')
		$price = get_post_meta($post->id, "field_59c8eea589935", true);
	return $price;
}


add_filter('the_content','druyf_add_to_cart', 20,1);
function druyf_add_to_cart($content){
	global $post;
	if ($post->post_type !== 'wine') {return $content; }
	ob_start();
	?>
	<form action="" method="post">
		<input name="add-to-cart" type="hidden" value="<?php echo $post->ID ?>" />
		<input name="quantity" type="number" value="1" min="1"  />
		<input name="submit" type="submit" value="Add to cart" />
	</form>
	<?php
	return $content . ob_get_clean();
}


function new_modify_user_table( $column ) {
    $column['type_o_wine'] = 'Type of wine';
    $column['type_o_box'] = 'Box type';
    $column['no_bottles'] = 'No. bottles';
    $column['first_name'] = 'First Name';
    $column['last_name'] = 'Last Name';
    $column['sup_value'] = 'Subscription';
    return $column;
}
add_filter( 'manage_users_columns', 'new_modify_user_table' );

function new_modify_user_table_row( $val, $column_name, $user_id ) {
    switch ($column_name) {
        case 'type_o_wine' :
            return get_the_author_meta( 'type_o_wine', $user_id );
            break;
        case 'type_o_box' :
            return get_the_author_meta( 'type_o_box', $user_id );
            break;
        case 'no_bottles' :
            return get_the_author_meta( 'no_bottles', $user_id );
            break;
        case 'sup_value' :
            return get_the_author_meta( 'sup_value', $user_id );
            break;
        case 'first_name' :
            return get_the_author_meta( 'first_name', $user_id );
            break;
        case 'last_name' :
            return get_the_author_meta( 'last_name', $user_id );
            break;
        default:
    }
    return $val;
}
add_filter( 'manage_users_custom_column', 'new_modify_user_table_row', 10, 3 );
function default_comments_on( $data ) {
    if( $data['post_type'] == 'wine' ) {
        $data['comment_status'] = 'open';
    }

    return $data;
}
add_filter( 'wp_insert_post_data', 'default_comments_on' );

function filter_rest_allow_anonymous_comments() {
    return true;
}
add_filter('rest_allow_anonymous_comments','filter_rest_allow_anonymous_comments');


/**
 * Add the field "rating_data" to REST API responses for posts read and write
 */
add_action( 'rest_api_init', 'rating_register' );
function rating_register() {
    register_rest_field( 'comment',
        'rating_data',
        array(
            'get_callback'    => 'get_rating',
            'update_callback' => 'set_rating',
            'schema'          => null,
        )
    );
}
/**
 * Handler for getting custom field data.
 *
 * @since 0.1.0
 *
 * @param array $object The object from the response
 * @param string $field_name Name of field
 * @param WP_REST_Request $request Current request
 *
 * @return mixed
 */
function get_rating( $object, $field_name, $request ) {
    return get_comment_meta( $object[ 'id' ], $field_name );
}

/**
 * Handler for updating custom field data.
 *
 * @since 0.1.0
 *
 * @param mixed $value The value of the field
 * @param object $object The object from the response
 * @param string $field_name Name of field
 *
 * @return bool|int
 */


function set_rating( $value, $object, $field_name ) {
    if ( ! $value || ! is_string( $value ) ) {
        return;
    }
    return add_comment_meta( $object->comment_ID, $field_name, strip_tags( $value ) );

}
add_action( 'rest_api_init', 'avg_rating_register' );
function avg_rating_register() {
    register_rest_field( 'wine',
        'ima_avg_rating',
        array(
            'get_callback'    => 'get_avg_rating',
            'update_callback' => 'set_avg_rating',
            'schema'          => null,
        )
    );
}

function get_avg_rating( $object, $field_name, $request ) {
    return get_post_meta( $object[ 'id' ], $field_name );
}
function set_avg_rating( $value, $object, $field_name ) {
    if ( ! $value || ! is_string( $value ) ) {
        return;
    }
    return add_post_meta( $object->comment_ID, $field_name, strip_tags( $value ) );

}
add_action('comment_unapproved_to_approved', 'update_rating_avg');
add_action('comment_approved_to_unapproved', 'update_rating_avg');
add_action('comment_spam_to_approved', 'update_rating_avg');
add_action('comment_approved_to_spam', 'update_rating_avg');
add_action('comment_approved_to_trash', 'update_rating_avg');
add_action('comment_trash_to_approved', 'update_rating_avg');

function update_rating_avg($comment) {
	$comments = get_comments([
		'post_id'=> $comment->comment_post_ID,
		'status'=>'approve'
	]);
	$ratings = [];
	foreach ($comments as $comment) {
		$meta = json_decode(get_comment_meta( $comment->comment_ID, 'rating_data', true));
		if (!is_null($meta)) {
			$ratings[] = $meta->rate;
		}
	}
	$sum = array_sum($ratings);
	$count = count($ratings);
	
	if ($count > 0) {
		$avg = $sum/$count;
	} else {
		$avg = 0;
	}
	update_post_meta($comment->comment_post_ID,'ima_avg_rating',$avg);
	$database =get_home_path()."rating.log";

    file_put_contents($database,json_encode(['rating'=>$ratings,'avrg'=>$avg]));

};

function pa_comp_fix() {
	wp_register_script( 'select2', WC()->plugin_url() . '/assets/js/select2/select2.full.min.js', array( 'jquery' ) );
	wp_enqueue_script( 'select2' );

	wp_register_script( 'selectWoo', WC()->plugin_url() . '/assets/js/selectWoo/selectWoo.full.min.js', array( 'jquery' ) );
	wp_enqueue_script( 'selectWoo' );

	wp_register_script( 'wc-enhanced-select', WC()->plugin_url() . '/assets/js/admin/wc-enhanced-select.min.js', array( 'jquery', 'selectWoo' ) );
	wp_enqueue_script( 'wc-enhanced-select' );
}

add_action( 'admin_enqueue_scripts', 'pa_comp_fix' );


function wpb_sender_email( $original_email_address ) {
    return 'info@druyf.nl';
}

function wpb_sender_name( $original_email_from ) {
    return 'The Druyf team';
}

add_filter( 'wp_mail_from', 'wpb_sender_email' );
add_filter( 'wp_mail_from_name', 'wpb_sender_name' );